/*************************************************************************
 *                                                                       *
 *                       X Olimpiada Informatyczna                       *
 *                                                                       *
 *   Rozwizanie zadania: Liczby Przesmykw                              *
 *   Plik:                lic.cpp                                        *
 *   Autor:               Krzysztof Onak                                 *
 *************************************************************************/

#include <iostream>
#include <vector>
#include <string>
#include <utility>
using namespace std;

class DuzaLiczba {
// klasa duych dodatnich liczb cakowitych
public:

  DuzaLiczba(int malaLiczba = 0) : cyfry(0)
  // konstruktor, inicjacja zwyk liczb cakowit
  {
    // dodajemy kolejne cyfry naszej liczby
    while (malaLiczba != 0) {
      cyfry.push_back(malaLiczba % PODSTAWA);
      malaLiczba /= PODSTAWA;
    }
  }
  
  const DuzaLiczba& operator+=(const DuzaLiczba &skladnik)
  // zwikszenie liczby o podan warto
  {
    int przeniesienie = 0;
    int stop = max(cyfry.size(), skladnik.cyfry.size()); // wiksza z dugoci
    // zwyke dodawanie kolejnych cyfr w ptli
    for (int i = 0; i < stop; ++i) {
      przeniesienie += cyfra(i) + skladnik.cyfra(i);
      zmienCyfre(i, przeniesienie % PODSTAWA);
      przeniesienie /= PODSTAWA;
    }
    // sprawdzenie czy nie nastpio przepenienie
    if (przeniesienie != 0) zmienCyfre(stop, przeniesienie);
    return *this;
  }

  const DuzaLiczba& operator-=(const DuzaLiczba &odjemnik)
  // zmiejszenie liczby o podan warto;
  // zakadamy, e wynik odejmowania jest nieujemny
  {
    int przeniesienie = 0, stop = cyfry.size();
    // w ptli odejmujemy kolejne cyfry
    for (int i = 0; i < stop; ++i) {
      int roznica = przeniesienie + cyfra(i) - odjemnik.cyfra(i);
      if (roznica < 0) {
        przeniesienie = -1;
	roznica += PODSTAWA;
      } else {
        przeniesienie = 0;
      }
      zmienCyfre(i, roznica);
    }
    // jeli jakie pocztkowe cyfry si wyzeroway,
    // to je usuwamy
    while (!cyfry.empty() && cyfry.back() == 0)
      cyfry.pop_back();
    return *this;
  }
  
  bool operator<(const DuzaLiczba& druga) const
  // porwnanie dwch duych liczb
  {
    // jeli druga liczba jest dusza, to na pewno jest wiksza
    if (druga.cyfry.size() > cyfry.size()) return true;
    // w ptli porwnujemy kolejne cyfry
    for (int i = cyfry.size() - 1; i >= 0; --i) {
      int a = cyfra(i), b = druga.cyfra(i);
      if (a < b) return true;
      if (a > b) return false;
    }
    // liczby s rwne
    return false;
  }
  
private:

  // podstawa systemu, w ktrym wykonujemy dziaania
  static const int PODSTAWA = 1024*1024*1024; // = 2^30
  
  // kolejne cyfry liczby w systemie o podstawie PODSTAWA;
  // zakadamy, e najbardziej znaczca cyfra (o ile istnieje)
  // jest rna od zera
  vector<int> cyfry;
  
  int cyfra(int pos) const
  // zwraca podan cyfr z reprezentacji lub zero,
  // jeli cyfra wykracza poza reprezentacj
  {
    return (pos < (int)cyfry.size()) ? cyfry[pos] : 0;
  }

  void zmienCyfre(int pos, int wart)
  // jeli istnieje cyfra o numerze pos w reprezentacji,
  // to jest ona zamieniana na wart,
  // wpp. zakadamy, e powstaje nowa cyfra
  // rozszerzajca dotychczasow reprezentacj
  {
    if (pos < (int)cyfry.size())
      cyfry[pos] = wart;
    else
      cyfry.push_back(wart);
  }

};

// przydatne stae
const DuzaLiczba ZERO(0);
const DuzaLiczba JEDEN(1);

class LiczbyCiagow {
// podaje liczby cigw o zadanej dugoci przy ustalonej
// wartoci m (maksymalna liczba minusw pod rzd)
public:

  // inicjacja wartoci m
  LiczbyCiagow(int mm) : m(mm) {liczby.push_back(JEDEN);}
  
  const DuzaLiczba& operator[](int indeks) const
  // zwraca liczb cigw o dugoci indeks
  {
    // wartoci wynikajce z umowy
    if (indeks < -1) return ZERO;
    if (indeks == -1) return JEDEN;
    // ewentualne doliczenie brakujcych wartoci
    for (int i = liczby.size(); i <= indeks; ++i) {
      liczby.push_back(liczby[i - 1]);
      liczby[i] += liczby[i - 1];
      liczby[i] -= (*this)[i - m - 2];
    }
    return liczby[indeks];
  }
  
  // zwraca warto m
  int podajM() const {return m;}
  
private:
  // liczba m - ograniczenie na liczb minusw pod rzd
  int m;
  // wektor dotychczas obliczonych wartoci
  mutable vector<DuzaLiczba> liczby;
};

void odkoduj(const string &zakodowana, DuzaLiczba &odkodowana,
             const LiczbyCiagow &L)
// odkodowuje cig plusw i minusw zakodowana,
// wynik zapisuje w odkodowana,
// korzysta ze struktury podajcej liczby cigw L
{
  int rozmiar = zakodowana.size(), m = L.podajM();
  odkodowana = ZERO;
  // uwzgldniamy krtsze cigi
  for (int i = 1; i < rozmiar; ++i)
    odkodowana += L[i];
  for (int i = 0; i < rozmiar; ++i) {
    // niezmiennik: wynik = odkodowana + (numer cigu zakodowana[i..rozmiar-1]
    //                                    wrd cigw tej samej dugoci)
    int rozmiarPodciagu = rozmiar - i;
    odkodowana -= L[rozmiarPodciagu - m - 2];
    if (zakodowana[i] == '+') odkodowana += L[rozmiarPodciagu - 1];
  }
}

void wypiszZakodowana(const DuzaLiczba &odkodowana, ostream &strumien,
                      const LiczbyCiagow &L)
// koduje liczbe odkodowana,
// wynik zapisuje bezporednio w strumieniu strumien,
// korzysta ze struktury podajcej liczby cigw L
{
  DuzaLiczba liczba = odkodowana;
  int m = L.podajM();
  int rozmiar;
  // ustalamy dugo cigu
  for (rozmiar = 1; !(liczba < L[rozmiar]); ++rozmiar)
    liczba -= L[rozmiar];
  // wypisujemy kolejne cyfry
  for (int i = rozmiar; i > 0; --i) {
    // w tej chwili pozostaje wypisa cig dugoci i
    // o numerze liczba wrd cigw tej dugoci
    liczba += L[i - m - 2]; // krtsze cigi psute przez pocztkowy minus
    // decyzja '+' czy '-'
    if (liczba < L[i - 1]) {
      strumien << '-';
    } else {
      strumien << '+';
      liczba -= L[i - 1];
    }
  }
}

int main()
// gwny program
{
  int m1, m2, n;
  cin >> m1 >> m2 >> n;
  LiczbyCiagow ciagiWejsciowe(m1), ciagiWyjsciowe(m2);
  // w ptli przetwarzamy kolejne cigi wejciowe
  for (int i = 0; i < n; ++i) {
    string staraLiczba;
    // wczytanie cigu
    cin >> staraLiczba;
    DuzaLiczba odkodowana;
    // odkodowanie
    odkoduj(staraLiczba, odkodowana, ciagiWejsciowe);
    // zakodowanie i zapisanie
    wypiszZakodowana(odkodowana, cout, ciagiWyjsciowe);
    cout << '\n';
  }
}
